
/* Beginning of labels */
#define AM_FILES		0
#define AM_OPEN_URL		1
#define AM_NEW_HTML		2
#define AM_NEW_HTML11		3
#define AM_NEW_HTML_TRANSITIONAL		4
#define AM_NEW_HTML_STRICT		5
#define AM_NEW_HTML_BASIC		6
#define AM_NEW_MATHML		7
#define AM_NEW_SVG		8
#define AM_NEW_CSS		9
#define AM_NEW_TEMPLATE		10
#define AM_OPEN_DOCUMENT		11
#define AM_INNEWTAB		12
#define AM_OPEN_IN_NEW_WINDOW		13
#define AM_CLEAR		14
#define AM_CLICK		15
#define AM_SAVED		16
#define AM_ATTRIBUTE		17
#define AM_HREF_VALUE		18
#define AM_TEXT		19
#define AM_NAME		20
#define AM_PASSWORD		21
#define AM_DEF_CLASS		22
#define AM_FETCHING		23
#define AM_CANNOT_LOAD		24
#define AM_DOCUMENT_LOADED		25
#define AM_SEL_TARGET		26
#define AM_INVALID_TARGET		27
#define AM_LOCATION		28
#define AM_TITLE		29
#define AM_CHANGE_TITLE		30
#define AM_DOC_MODIFIED		31
#define AM_RED_FETCHING		32
#define AM_REDIRECTIONS_LIMIT		33
#define AM_CANNOT_CREATE_FILE		34
#define AM_CANNOT_CREATE_DIRECTORY		35
#define AM_WAITING_FOR_SOCKET		36
#define AM_PROG_READ		37
#define AM_PROG_WRITE		38
#define AM_WAITING_FOR_CONNECTION		39
#define AM_CONTACTING_HOST		40
#define AM_LOOKING_HOST		41
#define AM_UNKNOWN_STATUS		42
#define AM_GET_AUTHENTICATION		43
#define AM_GET_AUTHENTICATION_MSG		44
#define AM_AUTHENTICATION_FAILURE		45
#define AM_LOADED_NO_DATA		46
#define AM_LOAD_ABORT		47
#define AM_NOT_AVAILABLE_RETRY		48
#define AM_ELEMENT_LOADED		49
#define AM_REMOTE_SAVING		50
#define AM_CANNOT_SAVE		51
#define AM_SYSTEM_ERROR		52
#define AM_INVALID_ANCHOR1		53
#define AM_INVALID_ANCHOR2		54
#define AM_GET_UNSUPPORTED_PROTOCOL		55
#define AM_PUT_UNSUPPORTED_PROTOCOL		56
#define AM_UNSUPPORTED_FEATURE		57
#define AM_WROTE_OBJECT		58
#define AM_BAD_URL		59
#define AM_CACHE_ERROR		60
#define AM_NO_TRANS		61
#define AM_TRANS_FAILED		62
#define AM_TRANS_PARSE_ERROR		63
#define AM_BUTTON_MATH		64
#define AM_BUTTON_GRAPHICS		65
#define AM_SAVE_AS		66
#define AM_AUTHENTICATION_REALM_SERVER		67
#define AM_AUTHENTICATION_REALM		68
#define AM_AUTHENTICATION_SERVER		69
#define AM_BUTTON_BrowseEdit		70
#define AM_REQUEST_TIMEOUT		71
#define AM_OVERWRITE_CHECK		72
#define AM_ETAG_CHANGED		73
#define AM_BACKGROUND_IMAGE		74
#define AM_BG_IMAGE_NOT_ALLOWED		75
#define AM_CSS		76
#define AM_WARNING_SAVE_OVERWRITE		77
#define AM_URL_SAVE_FAILED		78
#define AM_SAVE_DISK		79
#define AM_BCOPY_IMAGES		80
#define AM_BTRANSFORM_URL		81
#define AM_DOC_LOCATION		82
#define AM_IMAGES_LOCATION		83
#define AM_OBJECT_LOCATION		84
#define AM_CSS_FILE		85
#define AM_OPEN_CSS		86
#define AM_DISABLE_CSS		87
#define AM_ENABLE_CSS		88
#define AM_REMOVE_CSS		89
#define AM_ABOUT1		90
#define AM_ABOUT2		91
#define AM_TOO_LONG_URL		92
#define AM_INVALID_TYPE		93
#define AM_UPDATED_LINK		94
#define AM_NOTHING_TO_SAVE		95
#define AM_REPEAT_Y		96
#define AM_GET_USER_NAME		97
#define AM_WAITING_REQUESTS		98
#define AM_NO_CSS		99
#define AM_DONT_SAVE		100
#define AM_NO_REPEAT		101
#define AM_NO_NAME		102
#define AM_BUTTON_PLUGIN		103
#define AM_UNKNOWN_SAVE_ERROR		104
#define AM_CANT_CONNECT_TO_HOST		105
#define AM_FORBIDDEN_ACCESS		106
#define AM_REQUEST_SUCCEEDED		107
#define AM_CREATED_NEW_REMOTE_RESSOURCE		108
#define AM_UPDATED_REMOTE_RESSOURCE		109
#define AM_UNKNOWN_XXX_STATUS		110
#define AM_SERVER_DID_NOT_UNDERSTAND_REQ_SYNTAX		111
#define AM_NO_DATA		112
#define AM_METHOD_NOT_ALLOWED		113
#define AM_PLEASE_AUTHENTICATE		114
#define AM_VERIFYING		115
#define AM_SAVING_FAILED		116
#define AM_SAVE_COMPARE_FAILED		117
#define AM_SAVE_REDIRECTED		118
#define AM_SAVE_RELOAD_FAILED		119
#define AM_SERVER_INTERNAL_ERROR_500_CAUSE		120
#define AM_SERVER_NOT_IMPLEMENTED_501_ERROR		121
#define AM_PARSE		122
#define AM_ACTIVE_TRANSFERS		123
#define AM_WAITING_TRANSFERS		124
#define AM_PRINT_TOC		125
#define AM_NUMBERED_LINKS		126
#define AM_REPEAT_MODE		127
#define AM_REPEAT		128
#define AM_REPEAT_X		129
#define AM_RELOAD_FILES		130
#define AM_AUTHENTICATION_CONFIRM		131
#define AM_REDIRECTION_CONFIRM		132
#define AM_ROWS		133
#define AM_COLS		134
#define AM_BORDER		135
#define AM_ALT		136
#define AM_ALT_MISSING		137
#define AM_PRINT_URL		138
#define AM_APPLY_BUTTON		139
#define AM_DEFAULT_BUTTON		140
#define AM_FLUSH_CACHE_BUTTON		141
#define AM_CACHE_MENU		142
#define AM_ENABLE_CACHE		143
#define AM_CACHE_PROT_DOCS		144
#define AM_DISCONNECTED_MODE		145
#define AM_IGNORE_EXPIRES		146
#define AM_CACHE_DIR		147
#define AM_CACHE_SIZE		148
#define AM_CACHE_ENTRY_SIZE		149
#define AM_PROXY_MENU		150
#define AM_HTTP_PROXY		151
#define AM_PROXY_DOMAIN		152
#define AM_GENERAL_MENU		153
#define AM_HOME_PAGE		154
#define AM_TOOLTIP_DELAY		155
#define AM_DOUBLECLICK_DELAY		156
#define AM_MENU_FONT_SIZE		157
#define AM_ZOOM		158
#define AM_DIALOGUE_LANGUAGE		159
#define AM_PASTE_LINE_BY_LINE		160
#define AM_AUTO_SAVE		161
#define AM_SAVE_GEOMETRY_ON_EXIT		162
#define AM_SHOW_BG_IMAGES		163
#define AM_SHOW_BUTTONBAR		164
#define AM_SHOW_TEXTZONE		165
#define AM_SHOW_TARGETS		166
#define AM_EXPORT_CRLF		167
#define AM_BROWSE_MENU		168
#define AM_LOAD_IMAGES		169
#define AM_ENABLE_DOUBLECLICK		170
#define AM_PUBLISH_MENU		171
#define AM_USE_ETAGS		172
#define AM_VERIFY_PUT		173
#define AM_DEFAULT_NAME		174
#define AM_GEOMETRY_MENU		175
#define AM_SAVE_GEOMETRY		176
#define AM_RESTORE_GEOMETRY		177
#define AM_GEOMETRY_CHANGE		178
#define AM_COLOR_MENU		179
#define AM_DOC_FG_COLOR		180
#define AM_DOC_BG_COLOR		181
#define AM_MENU_FG_COLOR		182
#define AM_MENU_BG_COLOR		183
#define AM_CANT_CREATE_CACHE		184
#define AM_LANG_NEGOTIATION		185
#define AM_PROFILE_CHANGE		186
#define AM_SAFE_PUT_REDIRECT		187
#define AM_WITH_CSS		188
#define AM_TRANS		189
#define AM_PROXY_DOMAIN_INFO		190
#define AM_DONT_PROXY_DOMAIN		191
#define AM_ONLY_PROXY_DOMAIN		192
#define AM_MATH_ENTITY_NAME		193
#define AM_USER_DIR		194
#define AM_TMP_DIR		195
#define AM_COLOR_PALETTE		196
#define AM_LANNEG_MENU		197
#define AM_ANNOT_CONF_MENU		198
#define AM_ANNOT_USER		199
#define AM_ANNOT_POST_SERVER		200
#define AM_ANNOT_SERVERS		201
#define AM_ANNOT_LAUTOLOAD		202
#define AM_ANNOT_RAUTOLOAD		203
#define AM_ANNOT_RAUTOLOAD_RST		204
#define AM_FG_SEL_COLOR		205
#define AM_BG_SEL_COLOR		206
#define AM_ORIENTATION		207
#define AM_PORTRAIT		208
#define AM_LANDSCAPE		209
#define AM_INSERT_NBSP		210
#define AM_XML_RETRY		211
#define AM_XML_ERROR		212
#define AM_XML_CHARACTER_RETRY		213
#define AM_XML_CHARACTER_ERROR		214
#define AM_XML_PROFILE		215
#define AM_XML_WARNING		216
#define AM_UNKNOWN_ENCODING		217
#define AM_XML_MISMATCH_PROFILE		218
#define AM_NOT_AVAILABLE		219
#define AM_BROWSE		220
#define AM_FILE_BROWSER		221
#define AM_SELECTION		222
#define AM_AFILTER		223
#define AM_AFILTER_SHOW		224
#define AM_AFILTER_HIDE		225
#define AM_AFILTER_SHOW_ALL		226
#define AM_AFILTER_HIDE_ALL		227
#define AM_AFILTER_HELP		228
#define AM_AFILTER_OPTIONS		229
#define AM_AFILTER_BYAUTHOR		230
#define AM_AFILTER_BYTYPE		231
#define AM_AFILTER_BYSERVER		232
#define AM_ACCESSKEY		233
#define AM_NONE		234
#define AM_LOCAL_CSS		235
#define AM_NO_XPOINTER		236
#define AM_NO_SXPOINTER		237
#define AM_NO_EXPOINTER		238
#define AM_NO_ANNOT_MOVE		239
#define AM_NO_ANNOT_MOVE_OTHER		240
#define AM_NO_ANNOT_MOD_DOC		241
#define AM_NO_ANNOT_USER		242
#define AM_CANNOT_ANNOTATE		243
#define AM_NEW_ANNOTATION		244
#define AM_ANNOT_POST_FAILURE		245
#define AM_ANNOT_DELETE_FAILURE		246
#define AM_ANNOT_DELETED		247
#define AM_ANNOT_INDEX_FAILURE		248
#define AM_ERROR		249
#define AM_SELECT_CHARSET		250
#define AM_SELECT_MIMETYPE		251
#define AM_CHANGE_CHARSET		252
#define AM_CHANGE_MIME_TYPE		253
#define AM_CHANGE		254
#define AM_NOCHARSET_SUPPORT		255
#define AM_NOMIMETYPE_SUPPORT		256
#define AM_INVALID_MIMETYPE		257
#define AM_UNKNOWN		258
#define AM_CSS_ERROR		259
#define AM_DOUBLE_LOAD		260
#define AM_UNSAVE		261
#define AM_CHANGE_DOCTYPE1		262
#define AM_CHANGE_DOCTYPE2		263
#define AM_USE_XHTML_MIMETYPE		264
#define AM_DEFAULT_CHARSET		265
#define AM_LOCK_SUCCEED		266
#define AM_LOCK_FAILED		267
#define AM_LOCKING		268
#define AM_LOCKED		269
#define AM_LOCKED_BY_OTHER		270
#define AM_LOCK_OVERWRITE		271
#define AM_COPY_LOCK		272
#define AM_UNLOCK_BEFORE		273
#define AM_UNLOCK_SUCCEED		274
#define AM_UNLOCK_FAILED		275
#define AM_UNLOCKING		276
#define AM_UNLOCKED		277
#define AM_UNLOCK_DOCUMENT		278
#define AM_DAV_PROPERTIES		279
#define AM_PROPFIND_FAILED		280
#define AM_PROPFIND_FAILED_TEMP		281
#define AM_FINDING_PROPERTIES		282
#define AM_DAV_UNSUPPORTED_PROTOCOL		283
#define AM_SAVE_LOCKBASE_FAILED		284
#define AM_REMOVE_LOCKBASE_FAILED		285
#define AM_DAV_NOT_ALLOWED		286
#define AM_FAILED_DEPENDENCY		287
#define AM_MULTI_STATUS_FAIL		288
#define AM_DAV_TRY_AGAIN		289
#define AM_DAV_PREFERENCES		290
#define AM_DAV_USER_URL		291
#define AM_DAV_USER_RESOURCES		292
#define AM_DAV_DEPTH		293
#define AM_DAV_DEPTH_INFINITY		294
#define AM_DAV_TIMEOUT		295
#define AM_DAV_TIMEOUT_INFINITE		296
#define AM_DAV_TIMEOUT_OTHER		297
#define AM_DAV_LOCKSCOPE		298
#define AM_DAV_LOCKSCOPE_EXCLUSIVE		299
#define AM_DAV_LOCKSCOPE_SHARED		300
#define AM_DAV_AWARENESS		301
#define AM_DAV_AWARENESS_GENERAL		302
#define AM_DAV_AWARENESS_ONEXIT		303
#define AM_BUTTON_ANIM		304
#define AM_BUTTON_SVG_LIBRARY		305
#define AM_SVGLIB_DIALOG1		306
#define AM_SVGLIB_COPY_SELECTION		307
#define AM_SVGLIB_REF_SELECTION		308
#define AM_SVGLIB_ADD_SVG_MODEL_DIALOG		309
#define AM_SVGLIB_CREATE_NEW_SVG_FILE		310
#define AM_SVGLIB_CATALOGUE_TITLE		311
#define AM_SVGLIB_CATALOGUE_URL		312
#define AM_SVGLIB_CREATE_NEW_CATALOGUE		313
#define AM_SVGLIB_ADD_NEW_CATALOGUE		314
#define AM_SVGLIB_CREATE_NEW_CATALOGUE_DIALOG		315
#define AM_SVGLIB_NO_SVG_SELECTION		316
#define AM_SVGLIB_MISSING_TITLE		317
#define AM_SVGANIM_MOTION_HINT1		318
#define AM_SVGANIM_MOTION_HINT2		319
#define AM_SVGANIM_COLOR_HINT1		320
#define AM_SVGANIM_COLOR_HINT2		321
#define AM_SVGANIM_COLOR_HINT3		322
#define AM_SVGANIM_ANIM_DEFINED		323
#define AM_SVGANIM_ANIMATED_ATTR		324
#define AM_SVGANIM_NO_ID		325
#define ADD_ID		326
#define REMOVE_ID		327
#define ADD_REMOVE_ID		328
#define APPLY_OPERATION		329
#define ENTER_ELEMENT_NAME		330
#define AM_LOAD_CSS		331
#define AM_SCREEN_TYPE		332
#define AM_NEW_TOPIC		333
#define AM_BM_BPROPERTIES		334
#define AM_BM_TPROPERTIES		335
#define AM_BM_TOPIC_HIERARCHY		336
#define AM_BM_TITLE		337
#define AM_BM_RECALLS		338
#define AM_BM_AUTHOR		339
#define AM_BM_CREATED		340
#define AM_BM_MODIFIED		341
#define AM_BM_DESCRIPTION		342
#define AM_NO_SELECTION		343
#define AM_ALL_CSS		344
#define AM_STYLE_APPLIED		345
#define AM_LINK_LINE		346
#define AM_LOAD_OBJECTS		347
#define AM_NO_STYLE_FOR_ELEM		348
#define AM_NO_INSERT_POINT		349
#define AM_DOCINFO_TITLE		350
#define AM_DOCINFO_TYPE		351
#define AM_DOCINFO_TYPEMIME		352
#define AM_DOCINFO_CHARSET		353
#define AM_DOCINFO_CLENGTH		354
#define AM_DOCINFO_CLOCATION		355
#define AM_DLGPREFERENCE_TITLE		356
#define AM_MEntity		357
#define AM_NEWOBJECT		358
#define AM_DIRECTORY		359
#define AM_FILE		360
#define AM_REPLACECURRENT		361
#define AM_INNEWWINDOW		362
#define AM_NOALIASING		363
#define AM_DATE		364
#define AM_NEWDOCLOC		365
#define AM_OPENLOC		366
#define AM_WARNCTAB		367
#define AM_MAXURLLIST		368
#define AM_CLEARURLLIST		369
#define AM_SHOWSHORTCUTS		370
#define AM_EXPORT_LENGTH		371
#define AM_TEMPLATE		372
#define AM_TEMPLATE_INSTANCE		373
#define AM_BAD_TEMPLATE		374
#define AM_SHOW_TEMPLATES		375
#define AM_CLOSE_WHEN_APPLY		376
#define AM_NOT_ALLOWED		377
#define AM_READONLY		378
#define AM_INVALID_INLINE		379
#define AM_NO_HEADING_FOUND		380
#define AM_SAVE_ANYWAY		381
#define AM_NO_HOST		382
#define AM_DOC_CHANGED		383
#define AM_CONFLICT		384
#define AM_INVALID_SELECTION		385
#define AM_INVALID_ELEMENT		386
#define AM_CHANGE_NUMBER		387
#define AM_MISSING_TITLE		388
#define AM_TEMPLATES		389
#define AM_NUMBER_OCCUR		390
#define AM_NUMBER_OCCUR_HAVE_MAX		391
#define AM_NUMBER_OCCUR_HAVE_MIN		392
#define AM_WARNIDS		393
#define AM_MATHPI		394
#define AM_SELECT_OPERATOR_TITLE		395
#define AM_SELECT_OPERATOR_LABEL		396
#define AM_SELECT_INTEGRAL_TITLE		397
#define AM_SELECT_INTEGRAL_LABEL		398
#define AM_SELECT_FENCE_TITLE		399
#define AM_SELECT_FENCE_LABEL		400
#define AM_NUMBER_OPERATORS		401
#define AM_NUMBER_COORDONNATES		402
#define AM_NUMBER_NUPLE		403
#define AM_NUMBER_ELEMENTS		404
#define AM_NUMBER_VARIABLES		405
#define AM_DEGREE		406
#define AM_DEGREE_VARIABLE		407
#define AM_COMPOUND_DOCUMENT		408
#define AMAYA_MSG_MAX		409
